<?php

/*
 * @package RS-MINI
 * @copyright (c) 2015 Alexey Glumov aka Rio-Shaman (support@rio-shaman.ru)
 * @license GNU General Public License version 2; see LICENSE.txt
 *
 */
 
namespace core;

if(!defined('RS-MINI')) die();

/*
 * abstractview v 1.0
 * 
 * абстрактный класс для шаблонов
 *
 */

abstract class abstractview
{
    /*
     * объект дома
     *
     * @var    - object
     * @access - protected
     */
    
    protected $dom;
    
    /*
     * объект выбранного шаблона для запуска (заполняется с помощью вызова
     * метода getTpl())
     *
     * @var    - object
     * @access - private
     */
    
    private $currentTpl;
    
    /*
     * список (массив) шаблонов
     *
     * @var    - array
     * @access - private
     */
    
    private static $tplList;

    /*
     * конструктор
     * 
     * @access - public
     *
     * @param object dom - объект класса dom
     */
    
    public function __construct($dom)
    {
        $this->dom = $dom;
    }
    
    /*
     * метод объявляет массив с объектами шаблонов
     * вызывается один раз из view.class.php
     * 
     * @access - public
     *
     * @param array tplList - массив с шаблонами
     */
    
    public function setTplList(&$tplList)
    {
        self::$tplList = $tplList;
    }
    
    /*
     * метод получает шаблон по имени
     * 
     * @access - public
     * @return - сам себя
     *
     * @param string name - имя шаблона
     */
    
    public function getTpl($name)
    {
        // сбрасываем свойства выбора шаблона
        $this->currentTpl = FALSE;
        
        // если вызываемый шаблон существует
        if (isset(self::$tplList[$name]))
            // перенесим его объект в свойство выбора
            $this->currentTpl = self::$tplList[$name];
            
        return $this;
    }
    
    /*
     * запуск шаблона (!!!вызов производить только через этот метод)
     * 
     * @access - public
     * 
     */

    public function run()
    {
        // если выбор был сделан
        if ($this->currentTpl)
            // получаем ответ шаблона
            $this->currentTpl->getResponse();
            
        // в противном случае ничего не произойдет
    }
    
    /*
     * получить ответ шаблона
     * 
     * @access - public
     * 
     */

    public function getResponse()
    {
        
    }
}
